==> gaza_machine-0.0.1.tar.gz: lib/src/remote/machine_server.dart <==
// ignore_for_file: unused_import

import 'dart:io';

import 'package:gaza_machine/gaza_machine.dart';
import 'package:gaza_machine/src/base/machine.dart';
import 'package:gaza_machine/src/generated/grpc/machine.pbgrpc.dart';
import 'package:gaza_machine/src/local_machine.dart';
import 'package:gaza_machine/src/remote/machine_client.dart';
import 'package:gaza_machine/src/services/shell_service.dart';
import 'package:gaza_machine/src/services/system_service.dart';
import 'package:grpc/grpc.dart';

class MachineServer {
  String pMachineDir;
  int _port;
  MachineServer(this._port, this.pMachineDir);

  static Future<int> _getUnusedPort() async {
    final server = await ServerSocket.bind(InternetAddress.anyIPv4, 0);
    final port = server.port;
    await server.close();
    return port;
  }

  bool _isRunning = false;

  Server? _server;

  /// Get the current port.
  int get port => _port;

  /// Is the server running?
  bool get isRunning => _isRunning;

  /// Start the server.
  Future start() async {
    if (isRunning) return;
    _server = Server(
      [
        SystemService(pMachineDir).service,
        // SystemService(pMachineDir),
        // ShellService(pMachineDir),
      ],
      const <Interceptor>[],
      CodecRegistry(codecs: const [GzipCodec(), IdentityCodec()]),
    );

    if (_port == 0) _port = await _getUnusedPort();

    await _server!.serve(port: _port);
    _isRunning = true;
  }

  /// Stop the server.
  Future stop() async {
    if (!isRunning) return;
    await _server!.shutdown();
    _isRunning = false;
  }

  /// Change the current port.
  Future newPort([int? newPort]) async {
    newPort ??= await _getUnusedPort();
    await stop();
    final oldPort = _port;
    _port = newPort;
    try {
      await start();
    } catch (e) {
      _port = oldPort;
      rethrow;
    }
  }

  /// Local Client.
  LocalMachine get localClient => LocalMachine(pMachineDir);

  /// Connect to the machine over the network.
  MachineClient get client => GazaMachine.connect(port);
}

==> gaza_machine-0.0.2.tar.gz: lib/src/remote/machine_server.dart <==
// ignore_for_file: unused_import

import 'dart:io';

import 'package:gaza_machine/gaza_machine.dart';
import 'package:gaza_machine/src/base/machine.dart';
import 'package:gaza_machine/src/generated/grpc/machine/machine.pbgrpc.dart';
import 'package:gaza_machine/src/local_machine.dart';
import 'package:gaza_machine/src/remote/machine_client.dart';
import 'package:gaza_machine/src/services/shell_service.dart';
import 'package:gaza_machine/src/services/system_service.dart';
import 'package:grpc/grpc.dart';

class MachineServer {
  String _pMachineDir;
  int _port;
  MachineServer(this._port, this._pMachineDir);

  static Future<int> _getUnusedPort() async {
    final server = await ServerSocket.bind(InternetAddress.anyIPv4, 0);
    final port = server.port;
    await server.close();
    return port;
  }

  bool _isRunning = false;

  Server? _server;

  /// Get the current port.
  int get port => _port;

  /// Is the server running?
  bool get isRunning => _isRunning;

  /// Get the machine directory.
  String get machineDir => _pMachineDir;

  /// Start the server.
  Future start() async {
    if (isRunning) return;
    _server = Server(
      [
        SystemService(_pMachineDir).service,
        // SystemService(pMachineDir),
        // ShellService(pMachineDir),
      ],
      const <Interceptor>[],
      CodecRegistry(codecs: const [GzipCodec(), IdentityCodec()]),
    );

    if (_port == 0) _port = await _getUnusedPort();

    await _server!.serve(port: _port);
    _isRunning = true;
  }

  /// Stop the server.
  Future stop() async {
    if (!isRunning) return;
    await _server!.shutdown();
    _isRunning = false;
  }

  /// Change the current port.
  Future newPort([int? newPort]) async {
    newPort ??= await _getUnusedPort();
    await stop();
    final oldPort = _port;
    _port = newPort;
    try {
      await start();
    } catch (e) {
      _port = oldPort;
      rethrow;
    }
  }

  /// Local Client.
  LocalMachine get localClient => LocalMachine(_pMachineDir);

  /// Connect to the machine over the network.
  MachineClient get client => GazaMachine.connect(port);
}
